@@ -180,7 +180,7 @@
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"/>
+        <translation>Kjøp fullversjonen</translation>
     </message>
     <message>
         <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
@@ -260,6 +260,36 @@
         <translation>Søk bakover</translation>
     </message>
 </context>
+<context>
+    <name>LastFm</name>
+    <message>
+        <source>Authentication failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>LastFmLoginDialog</name>
+    <message>
+        <source>Log in to %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Username:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Password:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Signup for a %1 account</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -338,10 +368,6 @@
         <source>&amp;Quit</source>
         <translation>&amp;Avslutt</translation>
     </message>
-    <message>
-        <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
-    </message>
     <message>
         <source>Bye</source>
         <translation>Farvel</translation>
@@ -406,10 +432,6 @@
         <source>Mute volume</source>
         <translation>Demp lyden</translation>
     </message>
-    <message>
-        <source>Ctrl+M</source>
-        <translation>Ctrl+M</translation>
-    </message>
     <message>
         <source>&amp;Application</source>
         <translation>&amp;Applikasjon</translation>
@@ -480,7 +502,7 @@
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"/>
+        <translation>Kjøp fullversjonen</translation>
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
@@ -498,6 +520,38 @@
         <source>Update</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Minimize</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation>&amp;Steng</translation>
+    </message>
+    <message>
+        <source>Buy %1...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Stop After This Track</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Scrobbling</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Send played tracks titles to %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Log Out from %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
