@@ -40,7 +40,7 @@
     </message>
     <message>
         <source>%1, a YouTube music player</source>
-        <translation type="unfinished"/>
+        <translation>%1, музички плејер за Јутјуб</translation>
     </message>
     <message>
         <source>Translate %1 to your native language using %2</source>
@@ -62,7 +62,7 @@
     <name>ArtistInfo</name>
     <message>
         <source>Read more</source>
-        <translation type="unfinished"/>
+        <translation>Сазнајте више</translation>
     </message>
 </context>
 <context>
@@ -160,27 +160,27 @@
     <name>DemoStartupView</name>
     <message>
         <source>Please license %1</source>
-        <translation type="unfinished"/>
+        <translation>Молимо да купите %1</translation>
     </message>
     <message>
         <source>This demo has expired.</source>
-        <translation type="unfinished"/>
+        <translation>Показна верзија је истекла.</translation>
     </message>
     <message>
         <source>This demo will expire in %1 days.</source>
-        <translation type="unfinished"/>
+        <translation>Верзија ће истећи за %1 дана.</translation>
     </message>
     <message>
         <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
-        <translation type="unfinished"/>
+        <translation>Куповином пуне верзије ћете уједно и подржати мој рад на програму %1.</translation>
     </message>
     <message>
         <source>Use Demo</source>
-        <translation type="unfinished"/>
+        <translation>Користи показну верзију</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"/>
+        <translation>Преузмите пуну верзију</translation>
     </message>
     <message>
         <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
@@ -260,6 +260,36 @@
         <translation>Премотај уназад</translation>
     </message>
 </context>
+<context>
+    <name>LastFm</name>
+    <message>
+        <source>Authentication failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>LastFmLoginDialog</name>
+    <message>
+        <source>Log in to %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Username:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Password:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Signup for a %1 account</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -338,10 +368,6 @@
         <source>&amp;Quit</source>
         <translation>&amp;Напусти</translation>
     </message>
-    <message>
-        <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
-    </message>
     <message>
         <source>Bye</source>
         <translation>Ћао</translation>
@@ -406,10 +432,6 @@
         <source>Mute volume</source>
         <translation>Угаси звук</translation>
     </message>
-    <message>
-        <source>Ctrl+M</source>
-        <translation>Ctrl+M</translation>
-    </message>
     <message>
         <source>&amp;Application</source>
         <translation>Про&amp;грам</translation>
@@ -464,7 +486,7 @@
     </message>
     <message>
         <source>Remaining time: %1</source>
-        <translation type="unfinished"/>
+        <translation>Преостало време: %1</translation>
     </message>
     <message>
         <source>Volume at %1%</source>
@@ -480,7 +502,7 @@
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"/>
+        <translation>Преузмите пуну верзију</translation>
     </message>
     <message>
         <source>%1 version %2 is now available.</source>
@@ -496,6 +518,38 @@
     </message>
     <message>
         <source>Update</source>
+        <translation>Ажурирај</translation>
+    </message>
+    <message>
+        <source>&amp;Window</source>
+        <translation>&amp;Прозор</translation>
+    </message>
+    <message>
+        <source>&amp;Minimize</source>
+        <translation>&amp;Минимизуј</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation>&amp;Затвори</translation>
+    </message>
+    <message>
+        <source>Buy %1...</source>
+        <translation>Купите %1....</translation>
+    </message>
+    <message>
+        <source>&amp;Stop After This Track</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Scrobbling</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Send played tracks titles to %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&amp;Log Out from %1</source>
         <translation type="unfinished"/>
     </message>
 </context>
